@@ -3,12 +3,19 @@ __all__ = [
     "APIKeyMissing",
     "APIAccessDenied",
     "APIInsufficientQuota",
-    "APIResourceNotFound"
+    "APIResourceNotFound",
+    "APICloudflareError"
 ]
 
 
+class APICloudflareError(Exception):
+    """Raised when there is an error using the API related to cloudflare"""
+    pass
+
+
 class APIKeyMissing(Exception):
     """Raised when the api key is not passed and the headers are empty"""
+    pass
 
 
 class APIFailure(Exception):
@@ -29,3 +36,7 @@ class APIInsufficientQuota(Exception):
 class APIResourceNotFound(Exception):
     """Raised when access is denied to the API"""
     pass
+
+class RequestTimeoutExceeded(Exception):
+    """Raised when access is denied to the API"""
+    pass
\ No newline at end of file
